"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .completionschoice import CompletionsChoice, CompletionsChoiceTypedDict
from .usage import Usage, UsageTypedDict
from friendli.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class CompletionsResultTypedDict(TypedDict):
    r"""Successfully generated completions."""

    choices: List[CompletionsChoiceTypedDict]
    usage: UsageTypedDict


class CompletionsResult(BaseModel):
    r"""Successfully generated completions."""

    choices: List[CompletionsChoice]

    usage: Usage
