"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from friendli.types import BaseModel
from typing_extensions import TypedDict


class DedicatedTokenizationBodyTypedDict(TypedDict):
    model: str
    r"""ID of target endpoint. If you want to send request to specific adapter, using \"ENDPOINT_ID:ADAPTER_ROUTE\" format."""
    prompt: str
    r"""Input text prompt to tokenize."""


class DedicatedTokenizationBody(BaseModel):
    model: str
    r"""ID of target endpoint. If you want to send request to specific adapter, using \"ENDPOINT_ID:ADAPTER_ROUTE\" format."""

    prompt: str
    r"""Input text prompt to tokenize."""
