"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .streamedtoolassistedchattoken import (
    StreamedToolAssistedChatToken,
    StreamedToolAssistedChatTokenTypedDict,
)
from .streamedtoolassistedchattoolstatus import (
    StreamedToolAssistedChatToolStatus,
    StreamedToolAssistedChatToolStatusTypedDict,
)
from typing import Union


StreamedToolAssistedChatResultTypedDict = Union[
    StreamedToolAssistedChatTokenTypedDict, StreamedToolAssistedChatToolStatusTypedDict
]
r"""A server-sent event containing chat completions content."""


StreamedToolAssistedChatResult = Union[
    StreamedToolAssistedChatToken, StreamedToolAssistedChatToolStatus
]
r"""A server-sent event containing chat completions content."""
