"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .streamedchatchoice import StreamedChatChoice, StreamedChatChoiceTypedDict
from friendli.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class StreamedToolAssistedChatTokenDataTypedDict(TypedDict):
    choices: List[StreamedChatChoiceTypedDict]
    created: int
    r"""The Unix timestamp (in seconds) for when the token sampled."""


class StreamedToolAssistedChatTokenData(BaseModel):
    choices: List[StreamedChatChoice]

    created: int
    r"""The Unix timestamp (in seconds) for when the token sampled."""


class StreamedToolAssistedChatTokenTypedDict(TypedDict):
    data: StreamedToolAssistedChatTokenDataTypedDict


class StreamedToolAssistedChatToken(BaseModel):
    data: StreamedToolAssistedChatTokenData
