"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .function import Function, FunctionTypedDict
from friendli.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


ToolType = Literal["function"]
r"""The type of the tool. Currently, only `function` is supported."""


class ToolTypedDict(TypedDict):
    type: ToolType
    r"""The type of the tool. Currently, only `function` is supported."""
    function: FunctionTypedDict


class Tool(BaseModel):
    type: ToolType
    r"""The type of the tool. Currently, only `function` is supported."""

    function: Function
