"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from friendli.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class ServerlessDetokenizationBodyTypedDict(TypedDict):
    model: NotRequired[str]
    r"""Code of the model to use. See [available model list](https://friendli.ai/docs/guides/serverless_endpoints/pricing#text-generation-models)."""
    tokens: NotRequired[List[int]]
    r"""A token sequence to detokenize."""


class ServerlessDetokenizationBody(BaseModel):
    model: Optional[str] = None
    r"""Code of the model to use. See [available model list](https://friendli.ai/docs/guides/serverless_endpoints/pricing#text-generation-models)."""

    tokens: Optional[List[int]] = None
    r"""A token sequence to detokenize."""
